==> haskell-genvalidity-property-1.0.0.0-174-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-genvalidity-property.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 genvalidity-property
version:              1.0.0.0
visibility:           public
id:                   genvalidity-property-1.0.0.0-AQDmoxZOPYOIzOGyvYSTbh
key:                  genvalidity-property-1.0.0.0-AQDmoxZOPYOIzOGyvYSTbh
license:              MIT
copyright:            Copyright: (c) 2016-2021 Tom Sydney Kerckhove
maintainer:           syd@cs-syd.eu
author:               Tom Sydney Kerckhove
homepage:             https://github.com/NorfairKing/validity#readme
synopsis:             Standard properties for functions on `Validity` types
category:             Testing
abi:                  6c596bef26493314206e014493646913
exposed:              True
exposed-modules:
    Test.Validity.Functions Test.Validity.Functions.CanFail
    Test.Validity.Functions.Equivalence
    Test.Validity.Functions.Idempotence Test.Validity.Functions.Inverse
    Test.Validity.Functions.Validity Test.Validity.GenValidity.Property
    Test.Validity.Operations Test.Validity.Operations.Associativity
    Test.Validity.Operations.Commutativity
    Test.Validity.Operations.Identity Test.Validity.Property
    Test.Validity.Property.Utils Test.Validity.Relations
    Test.Validity.Relations.Antireflexivity
    Test.Validity.Relations.Antisymmetry
    Test.Validity.Relations.Reflexivity
    Test.Validity.Relations.Symmetry
    Test.Validity.Relations.Transitivity
    Test.Validity.Shrinking.Property Test.Validity.Types

hidden-modules:       Paths_genvalidity_property
import-dirs:          /usr/lib/ghc-9.4.8/site-local/genvalidity-property-1.0.0.0
library-dirs:         /usr/lib/ghc-9.4.8/site-local/genvalidity-property-1.0.0.0
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/genvalidity-property-1.0.0.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-genvalidity-property
hs-libraries:         HSgenvalidity-property-1.0.0.0-AQDmoxZOPYOIzOGyvYSTbh
depends:
    QuickCheck-2.15.0.1-59GGzHy0g7bISHsBJt3oMz base-4.17.2.1
    genvalidity-1.1.1.0-2DIaSyb7RT63kIhuaMf75r
    hspec-2.11.1-GaBAeHlVc2ILTCU5OQF0sK
    pretty-show-1.10-Dwgsrh12Px3tJNgclFhNg
    validity-0.12.1.0-GQ7rCDVQgSr3uciq60bdym

haddock-interfaces:
    /usr/share/doc/haskell-genvalidity-property/html/genvalidity-property.haddock

haddock-html:         /usr/share/doc/haskell-genvalidity-property/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-genvalidity-property-1.0.0.0-175-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-genvalidity-property.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 genvalidity-property
version:              1.0.0.0
visibility:           public
id:                   genvalidity-property-1.0.0.0-3y0fmg7wPiaF8KW9qOVzSt
key:                  genvalidity-property-1.0.0.0-3y0fmg7wPiaF8KW9qOVzSt
license:              MIT
copyright:            Copyright: (c) 2016-2021 Tom Sydney Kerckhove
maintainer:           syd@cs-syd.eu
author:               Tom Sydney Kerckhove
homepage:             https://github.com/NorfairKing/validity#readme
synopsis:             Standard properties for functions on `Validity` types
category:             Testing
abi:                  626f75d0dde9dadc1d77b5a489c280f9
exposed:              True
exposed-modules:
    Test.Validity.Functions Test.Validity.Functions.CanFail
    Test.Validity.Functions.Equivalence
    Test.Validity.Functions.Idempotence Test.Validity.Functions.Inverse
    Test.Validity.Functions.Validity Test.Validity.GenValidity.Property
    Test.Validity.Operations Test.Validity.Operations.Associativity
    Test.Validity.Operations.Commutativity
    Test.Validity.Operations.Identity Test.Validity.Property
    Test.Validity.Property.Utils Test.Validity.Relations
    Test.Validity.Relations.Antireflexivity
    Test.Validity.Relations.Antisymmetry
    Test.Validity.Relations.Reflexivity
    Test.Validity.Relations.Symmetry
    Test.Validity.Relations.Transitivity
    Test.Validity.Shrinking.Property Test.Validity.Types

hidden-modules:       Paths_genvalidity_property
import-dirs:          /usr/lib/ghc-9.4.8/site-local/genvalidity-property-1.0.0.0
library-dirs:         /usr/lib/ghc-9.4.8/site-local/genvalidity-property-1.0.0.0
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/genvalidity-property-1.0.0.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-genvalidity-property
hs-libraries:         HSgenvalidity-property-1.0.0.0-3y0fmg7wPiaF8KW9qOVzSt
depends:
    QuickCheck-2.15.0.1-2pZpRuW8a4m1OLZKRhi2a3 base-4.17.2.1
    genvalidity-1.1.1.0-JIV5HbUp3f2DICLnGVXdPJ
    hspec-2.11.1-8Bmj0jriNwhJpDt5d3xUJM
    pretty-show-1.10-Dwgsrh12Px3tJNgclFhNg
    validity-0.12.1.0-Exp4GzYdrky1oHDwN3LUnA

haddock-interfaces:
    /usr/share/doc/haskell-genvalidity-property/html/genvalidity-property.haddock

haddock-html:         /usr/share/doc/haskell-genvalidity-property/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
